package VMOMI::DasVmPriority;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
